Mixed-Up Code Exercises
-----------------------

Answer the following **Mixed-Up Code** or **Activecode** questions to
assess what you have learned in this chapter.

.. selectquestion:: mucp_12_1_sq
   :fromid: mucp_12_1, mucp_12_1_ac_q
   :toggle:

.. selectquestion:: mucp_12_2_sq
   :fromid: mucp_12_2, mucp_12_2_ac_q
   :toggle:

.. selectquestion:: mucp_12_3_sq
   :fromid: mucp_12_3, mucp_12_3_ac_q
   :toggle:

.. selectquestion:: mucp_12_4_sq
   :fromid: mucp_12_4, mucp_12_4_ac_q
   :toggle:

.. selectquestion:: mucp_12_5_sq
   :fromid: mucp_12_5, mucp_12_5_ac_q
   :toggle:

.. selectquestion:: mucp_12_6_sq
   :fromid: mucp_12_6, mucp_12_6_ac_q
   :toggle:

.. selectquestion:: mucp_12_7_sq
   :fromid: mucp_12_7, mucp_12_7_ac_q
   :toggle:

.. selectquestion:: mucp_12_8_sq
   :fromid: mucp_12_8, mucp_12_8_ac_q
   :toggle:

.. selectquestion:: mucp_12_9_sq
   :fromid: mucp_12_9, mucp_12_9_ac_q
   :toggle:

.. selectquestion:: mucp_12_10_sq
   :fromid: mucp_12_10, mucp_12_10_ac_q
   :toggle:
